Method enum

Inheritance
Available extensions

Values

get → const Method
const Method('GET')
post → const Method
const Method('POST')
put → const Method
const Method('PUT')
delete → const Method
const Method('DELTE')
path → const Method
const Method('PATH')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromName(String name) Method

Constants

values → const List<Method>
A constant List of the values in this enum, in order of their declaration.