TRouter class

--- Router --- Stores multiple RouteHandler per HTTP method

Inheritance

Constructors

TRouter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(Method method, String path, HttpHandler handler) → void
delete(String path, HttpHandler handler) → void
override
find(Method method, String path, Map<String, String> outParams) RouteHandler?
override
get(String path, HttpHandler handler) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
path(String path, HttpHandler handler) → void
override
post(String path, HttpHandler handler) → void
override
put(String path, HttpHandler handler) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited