TServer class

Constructors

TServer()
factory

Properties

getPort int
no setter
hashCode int
The hash code for this object.
no setterinherited
isServerRunning bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(TServerListener eve) → void
delete(String path, OnReqCallback onRequest) → void
dispose() → void
get(String path, OnReqCallback onRequest) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notify() → void
onSocketListen(OnSocketCallback onWebSocket) → void
post(String path, OnReqCallback onRequest) → void
put(String path, OnReqCallback onRequest) → void
removeListener(TServerListener eve) → void
startListen({String address = '0.0.0.0', int port = 8080}) Future<void>
stop({bool force = false}) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance TServer
final