TRouterInterface class abstract
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
delete(
String path, HttpHandler handler) → void -
find(
Method method, String path, Map< String, String> outParams) → RouteHandler? -
get(
String path, HttpHandler handler) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
path(
String path, HttpHandler handler) → void -
post(
String path, HttpHandler handler) → void -
put(
String path, HttpHandler handler) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited