TServer class
--- TServer --- Main server class
Constructors
- TServer()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- host → String?
-
Your Start Server
host addressno setter - httpServer → HttpServer?
-
Core HttpServer Class
no setter
- isServerRunning → bool
-
Server is Running
no setter
- port → int
-
Your Start Server
PORTno setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setRouter(
TRouterInterface router) → void -
setSocketRouter(
TSocketRouter socketRouter) → void -
start(
String host, int port, {int backlog = 0, bool v6Only = false, void onStartServer()?}) → Future< void> - init Server
-
stop(
{bool force = false}) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- getInstance → TServer
-
no setter